Structs
- A2aMemory
Card - Exposes memory operations as A2A agent card endpoints.
- Aura
Memory Item - Aura memory entry as returned by GET /memory/ls.
- Aura
Memory Store - AuraMemoryStore — delegates to the Aura daemon when running, falls back to InMemoryStore otherwise.
- InMemory
Store - McpMemory
Provider - Exposes memory operations as MCP tool provider endpoints.
- Memory
Entry
Enums
Traits
Functions
- aura_
available - Returns true if the Aura daemon is reachable at localhost:7437.
- aura_
cli_ available - Returns true if the
auraCLI binary is on PATH. - aura_
memory_ add - Call
aura memory add <key> <value>via CLI. - aura_
memory_ get - Call
aura memory get <key>via CLI and return the value. - aura_
memory_ ls - Call
aura memory ls --jsonand return all entries. - aura_
memory_ rm - Call
aura memory rm <key>via CLI.